@@ -56,6 +56,7 @@
 #include "gjs/jsapi-util-args.h"
 #include "gjs/jsapi-util-root.h"
 #include "gjs/mem-private.h"
+#include "gjs/profiler-private.h"
 #include "util/log.h"
 
 class JSTracer;
@@ -311,6 +312,9 @@ bool ObjectBase::prop_getter(JSContext* cx, unsigned argc, JS::Value* vp) {
     JS::RootedString name(cx,
         gjs_dynamic_property_private_slot(&args.callee()).toString());
 
+    std::string fullName = priv->format_name() + "." + gjs_debug_string(name);
+    AutoProfilerLabel label(cx, "property getter", fullName.c_str());
+
     priv->debug_jsprop("Property getter", name, obj);
 
     if (priv->is_prototype())
@@ -383,6 +387,9 @@ bool ObjectBase::field_getter(JSContext* cx, unsigned argc, JS::Value* vp) {
     JS::RootedString name(cx,
         gjs_dynamic_property_private_slot(&args.callee()).toString());
 
+    std::string fullName = priv->format_name() + "." + gjs_debug_string(name);
+    AutoProfilerLabel label(cx, "field getter", fullName.c_str());
+
     priv->debug_jsprop("Field getter", name, obj);
 
     if (priv->is_prototype())
@@ -446,6 +453,9 @@ bool ObjectBase::prop_setter(JSContext* cx, unsigned argc, JS::Value* vp) {
     JS::RootedString name(cx,
         gjs_dynamic_property_private_slot(&args.callee()).toString());
 
+    std::string fullName = priv->format_name() + "." + gjs_debug_string(name);
+    AutoProfilerLabel label(cx, "property setter", fullName.c_str());
+
     priv->debug_jsprop("Property setter", name, obj);
 
     if (priv->is_prototype())
@@ -503,6 +513,9 @@ bool ObjectBase::field_setter(JSContext* cx, unsigned argc, JS::Value* vp) {
     JS::RootedString name(cx,
         gjs_dynamic_property_private_slot(&args.callee()).toString());
 
+    std::string fullName = priv->format_name() + "." + gjs_debug_string(name);
+    AutoProfilerLabel label(cx, "field setter", fullName.c_str());
+
     priv->debug_jsprop("Field setter", name, obj);
 
     if (priv->is_prototype())
@@ -1284,7 +1297,9 @@ void
 ObjectInstance::release_native_object(void)
 {
     discard_wrapper();
-    if (m_uses_toggle_ref)
+    if (m_gobj_disposed)
+        m_ptr.release();
+    else if (m_uses_toggle_ref)
         g_object_remove_toggle_ref(m_ptr.release(), wrapped_gobj_toggle_notify,
                                    nullptr);
     else
@@ -1466,9 +1481,6 @@ ObjectInstance::disassociate_js_gobject(void)
 {
     bool had_toggle_down, had_toggle_up;
 
-    if (!m_gobj_disposed)
-        g_object_weak_unref(m_ptr.get(), wrapped_gobj_dispose_notify, this);
-
     auto& toggle_queue = ToggleQueue::get_default();
     std::tie(had_toggle_down, had_toggle_up) = toggle_queue.cancel(m_ptr.get());
     if (had_toggle_down != had_toggle_up) {
@@ -1478,8 +1490,12 @@ ObjectInstance::disassociate_js_gobject(void)
             m_ptr.get(), type_name());
     }
 
-    /* Fist, remove the wrapper pointer from the wrapped GObject */
-    unset_object_qdata();
+    if (!m_gobj_disposed) {
+        g_object_weak_unref(m_ptr.get(), wrapped_gobj_dispose_notify, this);
+
+        /* Fist, remove the wrapper pointer from the wrapped GObject */
+        unset_object_qdata();
+    }
 
     /* Now release all the resources the current wrapper has */
     invalidate_closure_list(&m_closures);
@@ -1863,6 +1879,11 @@ ObjectInstance::connect_impl(JSContext          *context,
                              "callback", &callback))
         return false;
 
+    std::string dynamicString = format_name() + '.' +
+                                (after ? "connect_after" : "connect") + "('" +
+                                signal_name.get() + "')";
+    AutoProfilerLabel label(context, "", dynamicString.c_str());
+
     if (!JS::IsCallable(callback)) {
         gjs_throw(context, "second arg must be a callback");
         return false;
@@ -1919,6 +1940,10 @@ ObjectInstance::emit_impl(JSContext          *context,
                              "signal name", &signal_name))
         return false;
 
+    std::string dynamicString =
+        format_name() + "emit('" + signal_name.get() + "')";
+    AutoProfilerLabel label(context, "", dynamicString.c_str());
+
     if (!g_signal_parse_name(signal_name.get(), gtype(), &signal_id,
                              &signal_detail, false)) {
         gjs_throw(context, "No signal '%s' on object '%s'",
@@ -2216,6 +2241,9 @@ bool ObjectBase::init_gobject(JSContext* context, unsigned argc,
     if (!priv->check_is_instance(context, "initialize"))
         return false;
 
+    std::string dynamicString = priv->format_name() + "._init";
+    AutoProfilerLabel label(context, "", dynamicString.c_str());
+
     return priv->to_instance()->init_impl(context, argv, &obj);
 }
 
