@@ -71,19 +71,17 @@ ToggleQueue::is_queued(GObject *gobj) const
     return {has_toggle_down, has_toggle_up};
 }
 
-std::pair<bool, bool>
-ToggleQueue::cancel(GObject *gobj)
-{
+std::pair<bool, bool> ToggleQueue::cancel(GObject* gobj) {
     debug("cancel", gobj);
     std::lock_guard<std::mutex> hold(lock);
     bool had_toggle_down = find_and_erase_operation_locked(gobj, DOWN);
     bool had_toggle_up = find_and_erase_operation_locked(gobj, UP);
-    gjs_debug_lifecycle(GJS_DEBUG_GOBJECT, "ToggleQueue: %p (%s) was %s", gobj,
-                        G_OBJECT_TYPE_NAME(gobj),
-                        had_toggle_down && had_toggle_up ? "queued to toggle BOTH"
-                            : had_toggle_down ? "queued to toggle DOWN"
-                            : had_toggle_up ? "queued to toggle UP"
-                            : "not queued");
+    gjs_debug_lifecycle(GJS_DEBUG_GOBJECT, "ToggleQueue: %p was %s", gobj,
+                        had_toggle_down && had_toggle_up
+                            ? "queued to toggle BOTH"
+                        : had_toggle_down ? "queued to toggle DOWN"
+                        : had_toggle_up   ? "queued to toggle UP"
+                                          : "not queued");
     return {had_toggle_down, had_toggle_up};
 }
 
@@ -150,11 +148,11 @@ ToggleQueue::enqueue(GObject               *gobj,
      *
      * Taking a reference now would be bad anyway, since it would force
      * the object to toggle back up again.
-     */   
+     */
 
     std::lock_guard<std::mutex> hold(lock);
     q.push_back(item);
-    
+
     if (m_idle_id) {
         g_assert(((void) "Should always enqueue with the same handler",
                   m_toggle_handler == handler));
