@@ -752,24 +752,29 @@ bool GjsContextPrivate::should_exit(uint8_t* exit_code_p) const {
 }
 
 void GjsContextPrivate::start_draining_job_queue(void) {
-    if (!m_idle_drain_handler)
+    if (!m_idle_drain_handler) {
+        gjs_debug(GJS_DEBUG_CONTEXT, "Starting promise job queue handler");
         m_idle_drain_handler = g_idle_add_full(
             G_PRIORITY_DEFAULT, drain_job_queue_idle_handler, this, nullptr);
+    }
 }
 
 void GjsContextPrivate::stop_draining_job_queue(void) {
     m_draining_job_queue = false;
     if (m_idle_drain_handler) {
+        gjs_debug(GJS_DEBUG_CONTEXT, "Stopping promise job queue handler");
         g_source_remove(m_idle_drain_handler);
         m_idle_drain_handler = 0;
     }
 }
 
 gboolean GjsContextPrivate::drain_job_queue_idle_handler(void* data) {
+    gjs_debug(GJS_DEBUG_CONTEXT, "Promise job queue handler");
     auto* gjs = static_cast<GjsContextPrivate*>(data);
     gjs->runJobs(gjs->context());
     /* Uncatchable exceptions are swallowed here - no way to get a handle on
      * the main loop to exit it from this idle handler */
+    gjs_debug(GJS_DEBUG_CONTEXT, "Promise job queue handler finished");
     g_assert(gjs->empty() && gjs->m_idle_drain_handler == 0 &&
              "GjsContextPrivate::runJobs() should have emptied queue");
     return G_SOURCE_REMOVE;
@@ -780,14 +785,21 @@ JSObject* GjsContextPrivate::getIncumbentGlobal(JSContext* cx) {
     return JS::CurrentGlobalOrNull(cx);
 }
 
-/* See engine.cpp and JS::SetEnqueuePromiseJobCallback(). */
-bool GjsContextPrivate::enqueuePromiseJob(
-    JSContext* cx [[maybe_unused]], JS::HandleObject promise [[maybe_unused]],
-    JS::HandleObject job, JS::HandleObject allocation_site [[maybe_unused]],
-    JS::HandleObject incumbent_global [[maybe_unused]]) {
+// See engine.cpp and JS::SetJobQueue().
+bool GjsContextPrivate::enqueuePromiseJob(JSContext* cx [[maybe_unused]],
+                                          JS::HandleObject promise,
+                                          JS::HandleObject job,
+                                          JS::HandleObject allocation_site,
+                                          JS::HandleObject incumbent_global
+                                          [[maybe_unused]]) {
     g_assert(cx == m_cx);
     g_assert(from_cx(cx) == this);
 
+    gjs_debug(GJS_DEBUG_CONTEXT,
+              "Enqueue job %s, promise=%s, allocation site=%s",
+              gjs_debug_object(job).c_str(), gjs_debug_object(promise).c_str(),
+              gjs_debug_object(allocation_site).c_str());
+
     if (m_idle_drain_handler)
         g_assert(!empty());
     else
@@ -798,6 +810,7 @@ bool GjsContextPrivate::enqueuePromiseJob(
         return false;
     }
 
+    JS::JobQueueMayNotBeEmpty(m_cx);
     start_draining_job_queue();
     return true;
 }
@@ -855,6 +868,8 @@ bool GjsContextPrivate::run_jobs_fallible(void) {
         m_job_queue[ix] = nullptr;
         {
             JSAutoRealm ar(m_cx, job);
+            gjs_debug(GJS_DEBUG_CONTEXT, "handling job %s",
+                      gjs_debug_object(job).c_str());
             if (!JS::Call(m_cx, JS::UndefinedHandleValue, job, args, &rval)) {
                 /* Uncatchable exception - return false so that
                  * System.exit() works in the interactive shell and when
@@ -876,6 +891,7 @@ bool GjsContextPrivate::run_jobs_fallible(void) {
 
     m_job_queue.clear();
     stop_draining_job_queue();
+    JS::JobQueueIsEmpty(m_cx);
     return retval;
 }
 
@@ -883,19 +899,24 @@ class GjsContextPrivate::SavedQueue : public JS::JobQueue::SavedJobQueue {
  private:
     GjsContextPrivate* m_gjs;
     JS::PersistentRooted<JobQueueStorage> m_queue;
+    bool m_idle_was_pending : 1;
     bool m_was_draining : 1;
 
  public:
     explicit SavedQueue(GjsContextPrivate* gjs)
         : m_gjs(gjs),
           m_queue(gjs->m_cx, std::move(gjs->m_job_queue)),
+          m_idle_was_pending(gjs->m_idle_drain_handler != 0),
           m_was_draining(gjs->m_draining_job_queue) {
+        gjs_debug(GJS_DEBUG_CONTEXT, "Pausing job queue");
         gjs->stop_draining_job_queue();
     }
 
     ~SavedQueue(void) {
+        gjs_debug(GJS_DEBUG_CONTEXT, "Unpausing job queue");
         m_gjs->m_job_queue = std::move(m_queue.get());
-        if (m_was_draining)
+        m_gjs->m_draining_job_queue = m_was_draining;
+        if (m_idle_was_pending)
             m_gjs->start_draining_job_queue();
     }
 };
@@ -930,10 +951,10 @@ void GjsContextPrivate::unregister_unhandled_promise_rejection(uint64_t id) {
 /**
  * gjs_context_maybe_gc:
  * @context: a #GjsContext
- * 
+ *
  * Similar to the Spidermonkey JS_MaybeGC() call which
  * heuristically looks at JS runtime memory usage and
- * may initiate a garbage collection. 
+ * may initiate a garbage collection.
  *
  * This function always unconditionally invokes JS_MaybeGC(), but
  * additionally looks at memory usage from the system malloc()
@@ -947,7 +968,7 @@ void GjsContextPrivate::unregister_unhandled_promise_rejection(uint64_t id) {
  *
  * A good time to call this function is when your application
  * transitions to an idle state.
- */ 
+ */
 void
 gjs_context_maybe_gc (GjsContext  *context)
 {
@@ -958,10 +979,10 @@ gjs_context_maybe_gc (GjsContext  *context)
 /**
  * gjs_context_gc:
  * @context: a #GjsContext
- * 
+ *
  * Initiate a full GC; may or may not block until complete.  This
  * function just calls Spidermonkey JS_GC().
- */ 
+ */
 void
 gjs_context_gc (GjsContext  *context)
 {
