@@ -21,6 +21,7 @@
 #include <js/GCAPI.h>  // for AutoCheckCannotGC
 #include <js/GCPolicyAPI.h>
 #include <js/Id.h>     // for JSID_IS_STRING...
+#include <js/Promise.h>
 #include <js/RootingAPI.h>
 #include <js/Symbol.h>
 #include <js/TypeDecls.h>
@@ -28,9 +29,11 @@
 #include <js/Value.h>
 #include <jsapi.h>        // for JSID_TO_FLAT_STRING, JS_GetTwoByte...
 #include <jsfriendapi.h>  // for FlatStringToLinearString, GetLatin...
+#include <mozilla/CheckedInt.h>
 
 #include "gjs/jsapi-util.h"
 #include "gjs/macros.h"
+#include "util/misc.h"  // for _gjs_memdup2
 
 // Avoid static_assert in MSVC builds
 namespace JS {
@@ -203,7 +206,14 @@ gjs_string_get_char16_data(JSContext       *context,
     if (js_data == NULL)
         return false;
 
-    *data_p = (char16_t *) g_memdup(js_data, sizeof(*js_data) * (*len_p));
+    mozilla::CheckedInt<size_t> len_bytes =
+        mozilla::CheckedInt<size_t>(*len_p) * sizeof(*js_data);
+    if (!len_bytes.isValid()) {
+        JS_ReportOutOfMemory(context);  // cannot call gjs_throw, it may GC
+        return false;
+    }
+
+    *data_p = static_cast<char16_t*>(_gjs_memdup2(js_data, len_bytes.value()));
 
     return true;
 }
@@ -453,6 +463,36 @@ gjs_debug_object(JSObject * const obj)
         return "<null object>";
 
     std::ostringstream out;
+
+    if (js::IsFunctionObject(obj)) {
+        JSFunction* fun = JS_GetObjectFunction(obj);
+        JSString* display_name = JS_GetFunctionDisplayId(fun);
+        if (display_name && JS_GetStringLength(display_name))
+            out << "<function " << gjs_debug_string(display_name);
+        else
+            out << "<anonymous function";
+        out << " at " << fun << '>';
+        return out.str();
+    }
+
+    // This is OK because the promise methods can't cause a garbage collection
+    JS::HandleObject handle = JS::HandleObject::fromMarkedLocation(&obj);
+    if (JS::IsPromiseObject(handle)) {
+        out << '<';
+        JS::PromiseState state = JS::GetPromiseState(handle);
+        if (state == JS::PromiseState::Pending)
+            out << "pending ";
+        out << "promise " << JS::GetPromiseID(handle) << " at " << obj;
+        if (state != JS::PromiseState::Pending) {
+            out << ' ';
+            out << (state == JS::PromiseState::Rejected ? "rejected"
+                                                        : "resolved");
+            out << " with " << gjs_debug_value(JS::GetPromiseResult(handle));
+        }
+        out << '>';
+        return out.str();
+    }
+
     const JSClass* clasp = JS_GetClass(obj);
     out << "<object " << clasp->name << " at " << obj <<  '>';
     return out.str();
@@ -482,16 +522,6 @@ gjs_debug_value(JS::Value v)
         out << gjs_debug_symbol(v.toSymbol());
         return out.str();
     }
-    if (v.isObject() && js::IsFunctionObject(&v.toObject())) {
-        JSFunction* fun = JS_GetObjectFunction(&v.toObject());
-        JSString *display_name = JS_GetFunctionDisplayId(fun);
-        if (display_name)
-            out << "<function " << gjs_debug_string(display_name);
-        else
-            out << "<unnamed function";
-        out << " at " << fun << '>';
-        return out.str();
-    }
     if (v.isObject()) {
         out << gjs_debug_object(&v.toObject());
         return out.str();
